@@ -27,7 +27,7 @@ static void timeout(int sig)
     exit(1);
 }
 
-void main(void)
+int main(void)
 {
     int vgamode, color, leftpressed;
     int x, y;
