@@ -204,7 +204,7 @@ void gl_line (int x1, int y1, int x2, int y2, int c)
 		    *((unsigned char *) (vp + 1)) = (c>>8);    \
 		    *((unsigned char *) (vp + 2)) = (c>>16);
 
-#define insert_pixel_4 *((unsigned long *) vp) = c;
+#define insert_pixel_4 *((unsigned int *) vp) = c;
 
     bytesperrow = BYTEWIDTH;
 
@@ -301,7 +301,7 @@ void gl_line (int x1, int y1, int x2, int y2, int c)
 		    *((unsigned char *) (vp + fp + 1)) = (c>>8);    \
 		    *((unsigned char *) (vp + fp + 2)) = (c>>16);
 
-#define insert_pixel_4 *((unsigned long *) (vp + fp)) = c;
+#define insert_pixel_4 *((unsigned int *) (vp + fp)) = c;
 
 
     if (MODETYPE == CONTEXT_PAGED) {
