@@ -591,7 +591,7 @@ int init_module(void)
     devfs_register_series( devfs_handle,
                "%u", 8, DEVFS_FL_DEFAULT, SVGALIB_HELPER_MAJOR, 0,
                        S_IFCHR |  S_IRUGO | S_IRWXU, &svgalib_helper_fops, NULL ) ;
-    devfs_mk_symlink( NULL, "svga", 0, "svga_helper/0", &slave_handle, NULL );
+    DEVFS_MK_SYMLINK( NULL, "svga", 0, "svga_helper/0", &slave_handle, NULL );
     devfs_auto_unregister( devfs_handle, slave_handle );
 # else
 	devfs_mk_dir ("svga_helper");
@@ -599,7 +599,7 @@ int init_module(void)
 		devfs_mk_cdev(MKDEV(SVGALIB_HELPER_MAJOR, i),
 				S_IFCHR |  S_IRUGO | S_IRWXU, "svga_helper/%d", i);
 	}
-	devfs_mk_symlink("svga", "svga_helper/0");
+	DEVFS_MK_SYMLINK("svga", "svga_helper/0");
 # endif
 #endif /* devfsd support */
 
