@@ -43,7 +43,7 @@ static int apm_init(int, int, int);
 static void apm_unlock(void);
 
 static int apm_memory,apm_chiptype;
-static int apm_is_linear,apm_xbase;
+static int apm_xbase;
 
 static CardSpecs *cardspecs;
 
@@ -59,7 +59,7 @@ static void outwXR(int index,unsigned short d)
     port_outw_r(apm_xbase,d);
 }
 
-static void outlXR(int index,unsigned long d)
+static void outlXR(int index,unsigned int d)
 {
     __svgalib_outseq(0x1d,index>>2);
     port_outl_r(apm_xbase,d);
@@ -80,7 +80,7 @@ static unsigned short inwXR(int index)
 }
 #endif
 
-static unsigned long inlXR(int index)
+static unsigned int inlXR(int index)
 {
     __svgalib_outseq(0x1d,index>>2);
     return port_inl(apm_xbase);
@@ -96,13 +96,7 @@ static void apm_setpage(int page)
     outwXR(0xc0,page << 4);
 }
 
-static int __svgalib_apm_inlinearmode(void)
-{
-    return apm_is_linear;
-}
-
 /* Fill in chipset specific mode information */
-
 static void apm_getmodeinfo(int mode, vga_modeinfo *modeinfo)
 {
     if(modeinfo->colors==16)return;
@@ -113,10 +107,8 @@ static void apm_getmodeinfo(int mode, vga_modeinfo *modeinfo)
     modeinfo->haveblit = 0;
     modeinfo->flags &= ~HAVE_RWPAGE;
 
-    if (modeinfo->bytesperpixel >= 1) {
-	modeinfo->flags |= CAPABLE_LINEAR;
-        if (__svgalib_apm_inlinearmode())
-	    modeinfo->flags |= IS_LINEAR | LINEAR_MODE;
+	if (modeinfo->bytesperpixel >= 1) {
+		modeinfo->flags |= CAPABLE_LINEAR;
     }
 }
 
@@ -124,8 +116,8 @@ static void apm_getmodeinfo(int mode, vga_modeinfo *modeinfo)
 
 static int apm_saveregs(unsigned char regs[])
 { 
-	unsigned long k;
-	unsigned long *p;
+	unsigned int k;
+	unsigned int *p;
 	unsigned short *q;
 
     apm_unlock();		/* May be locked again by other programs (e.g. X) */
@@ -151,15 +143,15 @@ static int apm_saveregs(unsigned char regs[])
    regs[APMREG_SAVE(15)] = (k >> 8)&0xff;
    regs[APMREG_SAVE(16)] = (k >> 16) & 0xff ;
    regs[APMREG_SAVE(17)] = ( k >> 24 ) & 0xff ;
-   p=(unsigned long *) &regs[APMREG_SAVE(18)];
+   p=(unsigned int *) &regs[APMREG_SAVE(18)];
    *p = inlXR(0xf0);
-   p=(unsigned long *) &regs[APMREG_SAVE(22)];
+   p=(unsigned int *) &regs[APMREG_SAVE(22)];
    *p = inlXR(0xf4);
-   p=(unsigned long *) &regs[APMREG_SAVE(26)];
+   p=(unsigned int *) &regs[APMREG_SAVE(26)];
    *p = inlXR(0x140);
    q=(unsigned short *) &regs[APMREG_SAVE(30)];
    *q = inlXR(0x144);
-   p=(unsigned long *) &regs[APMREG_SAVE(32)];
+   p=(unsigned int *) &regs[APMREG_SAVE(32)];
    *p = inXR(0x148);
    q=(unsigned short *) &regs[APMREG_SAVE(36)];
    *q = inXR(0x14c);
@@ -170,7 +162,7 @@ static int apm_saveregs(unsigned char regs[])
 /* Set chipset-specific registers */
 
 static void apm_setregs(const unsigned char regs[], int mode)
-{  unsigned long k ; 
+{  unsigned int k ; 
 
     apm_unlock();		/* May be locked again by other programs (eg. X) */
     apm_setpage(0);
@@ -241,7 +233,7 @@ static unsigned comp_lmn(unsigned clock) ;
 static void apm_initializemode(unsigned char *moderegs,
 			    ModeTiming * modetiming, ModeInfo * modeinfo, int mode)
 {
-    long k;
+    int k;
   
     apm_saveregs(moderegs);
     __svgalib_setup_VGA_registers(moderegs, modetiming, modeinfo);
@@ -362,10 +354,7 @@ static void apm_initializemode(unsigned char *moderegs,
     moderegs[APMREG_SAVE(12)] = 0x1f;   
     moderegs[APMREG_SAVE(13)] = 0x07;  
 
-    apm_is_linear=0;
-
-return ;
-
+	return ;
 }
 
 
@@ -466,13 +455,13 @@ static int apm_test(void)
     return 0;
 #else /* use PCI test */
    int found=0;
-   unsigned long buf[64];
+   unsigned int buf[64];
     
-   found=__svgalib_pci_find_vendor_vga(0x1142,buf,0);
-   if(found)return 0;
+   found=__svgalib_pci_find_vendor_vga_pos(0x1142,buf);
+   if(!found)return 0;
    if ((((buf[0]>>16)&0xffff)!=0x6424)&&
        (((buf[0]>>16)&0xffff)!=0x643d)
-       )return 0;
+       ) return 0;
    apm_init(0,0,0);
    return 1;
 #endif
@@ -518,11 +507,15 @@ static void apm_setlogicalwidth(int width)
 
 static int apm_linear(int op, int param)
 {
-if (op==LINEAR_ENABLE) { apm_is_linear=1; return 0;}
-if (op==LINEAR_DISABLE){ apm_is_linear=0; return 0;}
-if (op==LINEAR_QUERY_BASE) {__svgalib_outSR(0x1d,0x193>>2); return port_in(apm_xbase+3)<<24 ;}
-if (op == LINEAR_QUERY_RANGE || op == LINEAR_QUERY_GRANULARITY) return 0;		/* No granularity or range. */
-    else return -1;		/* Unknown function. */
+	if (op==LINEAR_ENABLE) { return 0;}
+	if (op==LINEAR_DISABLE){ return 0;}
+	if (op==LINEAR_QUERY_BASE) {
+		__svgalib_outSR(0x1d,0x193>>2); 
+		return port_in(apm_xbase+3)<<24;
+	}
+	if (op == LINEAR_QUERY_RANGE || op == LINEAR_QUERY_GRANULARITY) 
+		return 0;		/* No granularity or range. */
+	return -1;		/* Unknown function. */
 }
 
 static int apm_match_programmable_clock(int clock)
@@ -573,13 +566,13 @@ static int apm_init(int force, int par1, int par2)
 {
     char    idstring[]  = "       ";
     int found=0;
-    unsigned long buf[64];
+    unsigned int buf[64];
     int db, d9;
 
     apm_unlock();
 
-    found=__svgalib_pci_find_vendor_vga(0x1142,buf,0);
-    if(found)return 1;
+    found=__svgalib_pci_find_vendor_vga_pos(0x1142,buf);
+    if(!found)return 1;
     switch((buf[0]>>16)&0xffff) {
         case 0x6424: strcpy(idstring,"AT24"); break; 
         case 0x643d: strcpy(idstring,"AT25/3D"); break; 
@@ -603,8 +596,6 @@ static int apm_init(int force, int par1, int par2)
 	fprintf(stderr,"Using Alliance driver, %.7s, %iKB.\n",idstring, apm_memory);
     }
 
-    __svgalib_modeinfo_linearset = IS_LINEAR;
-
     apm_xbase= (__svgalib_inseq(0x1f) << 8 ) + __svgalib_inseq(0x1e);
     
     cardspecs = malloc(sizeof(CardSpecs));
