@@ -35,7 +35,7 @@ static void g400_unlock(void);
 static void g400_lock(void);
 
 static int g400_memory, id, g400_pciposition;
-static int g400_is_linear, g400_linear_base, g400_mmio_base;
+static unsigned int g400_linear_base, g400_mmio_base;
 
 static int HasSDRAM;
 
@@ -82,13 +82,7 @@ static void g400_setpage(int page)
     g400_outExt(4,page);
 }
 
-static int __svgalib_g400_inlinearmode(void)
-{
-    return g400_is_linear;
-}
-
 /* Fill in chipset specific mode information */
-
 static void g400_getmodeinfo(int mode, vga_modeinfo *modeinfo)
 {
 
@@ -101,9 +95,7 @@ static void g400_getmodeinfo(int mode, vga_modeinfo *modeinfo)
     modeinfo->flags &= ~HAVE_RWPAGE;
 
     if (modeinfo->bytesperpixel >= 1) {
-	if(g400_linear_base)modeinfo->flags |= CAPABLE_LINEAR;
-        if (__svgalib_g400_inlinearmode())
-	    modeinfo->flags |= IS_LINEAR | LINEAR_MODE;
+		if(g400_linear_base)modeinfo->flags |= CAPABLE_LINEAR;
     }
 }
 
@@ -228,7 +220,7 @@ static int g400_modeavailable(int mode)
 #define MGA_MAX_VCO_FREQ    310000
 
 static double
-MGACalcClock (long f_out,
+MGACalcClock (int f_out,
 		int *best_m, int *best_n, int *p, int *s )
 {
 	int m, n;
@@ -329,7 +321,7 @@ MGACalcClock (long f_out,
 	return f_pll;
 }
 
-static int MGASetPCLK(long f_out, unsigned char *initDAC )
+static int MGASetPCLK(int f_out, unsigned char *initDAC )
 {
 	/* Pixel clock values */
 	int m, n, p, s;
@@ -649,11 +641,11 @@ static void g400_lock(void)
 static int g400_test(void)
 {
     int found, id;
-    unsigned long buf[64];
+    unsigned int buf[64];
     
-    found=__svgalib_pci_find_vendor_vga(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
     
-    if(found) return 0;
+    if(!found) return 0;
     
     id=(buf[0]>>16)&0xffff;
     
@@ -689,11 +681,11 @@ static void g400_setlogicalwidth(int width)
 
 static int g400_linear(int op, int param)
 {
-    if (op==LINEAR_ENABLE){g400_is_linear=1; return 0;};
-    if (op==LINEAR_DISABLE){g400_is_linear=0; return 0;};
+    if (op==LINEAR_ENABLE || op==LINEAR_DISABLE) return 0;
     if (op==LINEAR_QUERY_BASE) return g400_linear_base;
-    if (op == LINEAR_QUERY_RANGE || op == LINEAR_QUERY_GRANULARITY) return 0;		/* No granularity or range. */
-        else return -1;		/* Unknown function. */
+    if (op == LINEAR_QUERY_RANGE || op == LINEAR_QUERY_GRANULARITY)
+		return 0;		/* No granularity or range. */
+	return -1;		/* Unknown function. */
 }
 
 static int g400_match_programmable_clock(int clock)
@@ -818,7 +810,7 @@ DriverSpecs __svgalib_g400_driverspecs =
 
 static int g400_init(int force, int par1, int par2)
 {
-    unsigned long buf[64];
+    unsigned int buf[64];
     int found=0;
     int pci_id;
     int max_mem = 8;
@@ -830,9 +822,9 @@ static int g400_init(int force, int par1, int par2)
 	g400_memory = 0;
     };
 
-    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
     
-    if(found==-1) {
+    if(!found) {
         fprintf(stderr,"Error: Must use Matrox driver, but no card found\n");
         exit(1);
     }
@@ -878,13 +870,13 @@ static int g400_init(int force, int par1, int par2)
     __svgalib_mm_io_mapio();
 
     if(!g400_memory) {
-        map_linear(g400_linear_base, max_mem*1024*1024);
-        g400_memory=memorytest(LINEAR_POINTER,max_mem);
-        unmap_linear(max_mem*1024*1024);
+        __svgalib_linear_mem_base=g400_linear_base;
+        __svgalib_linear_mem_size=max_mem*1024*1024;
+        map_linear(0);
+        g400_memory=memorytest((uint32_t *)LINEAR_POINTER,max_mem);
+        unmap_linear();
     }
 
-    __svgalib_modeinfo_linearset |= IS_LINEAR;
-    
     __svgalib_inpal=inpal;
     __svgalib_outpal=outpal;    
 
@@ -895,6 +887,8 @@ static int g400_init(int force, int par1, int par2)
            	g400_memory, HasSDRAM?'D':'G');
     };
 
+    __svgalib_modeinfo_linearset |= LINEAR_CAN;
+    
     cardspecs = malloc(sizeof(CardSpecs));
     cardspecs->videoMemory = g400_memory;
     cardspecs->maxPixelClock4bpp = 75000;
