@@ -67,12 +67,11 @@ static int init(int, int, int);
 static void unlock(void);
 
 static int memory, chip, nvnum, nvarch;
-static int is_linear;
 static CardSpecs *cardspecs;
 static int PLL_INPUT_FREQ, MAXVCLOCK, M_MIN, M_MAX, P_MAX;
 static int dualhead, twostagepll;
 
-static unsigned long MMIOBASE, LINEARBASE;
+static unsigned int MMIOBASE, LINEARBASE;
 
 enum {
  	Riva128 = 0, RivaTNT, GEFORCE
@@ -84,13 +83,8 @@ static void setpage(int page)
 	__svgalib_outcrtc(0x1e,page << 1);
 }
 
-static int inlinearmode(void)
-{
-	return is_linear;
-}
 
 /* Fill in chipset specific mode information */
-
 static void getmodeinfo(int mode, vga_modeinfo *modeinfo)
 {
    
@@ -104,8 +98,6 @@ static void getmodeinfo(int mode, vga_modeinfo *modeinfo)
 
    if (modeinfo->bytesperpixel >= 1) {
 	   modeinfo->flags |= CAPABLE_LINEAR;
-	   if (inlinearmode())
-		   modeinfo->flags |= IS_LINEAR | LINEAR_MODE;
 //	   if(chip==Riva128)
 //		   modeinfo->flags |= IOCTL_SETDISPLAY;
    }
@@ -319,7 +311,7 @@ static int CalculateCRTC(ModeTiming *mode, ModeInfo *modeinfo, unsigned char *mo
 static void initializemode(unsigned char *moderegs,
 			    ModeTiming * modetiming, ModeInfo * modeinfo, int mode)
 { 
-    long k;
+    int k;
     unsigned int config0=0;
 	struct nv_regs *save = (struct nv_regs *)moderegs;
     
@@ -402,8 +394,6 @@ static void initializemode(unsigned char *moderegs,
  	save->crtc[4]=28;
   	save->crtc[25]&=0xfe; /* hide cursor */
 
- 	is_linear=0;
-
 	return;
 }
 
@@ -494,12 +484,13 @@ static void lock(void)
 
 static int test(void)
 {
-	unsigned long buf[64];
+	unsigned int buf[64];
  	int found=0;
- 	found=__svgalib_pci_find_vendor_vga(0x12d2,buf,0);
- 	if (found) {
-  		found=__svgalib_pci_find_vendor_vga(0x10de,buf,0);
-  		if(found)return 0;
+ 	found=__svgalib_pci_find_vendor_vga_pos(0x12d2,buf);
+
+	if (!found) {
+  		found=__svgalib_pci_find_vendor_vga_pos(0x10de,buf);
+  		if(!found) return 0;
  	};
 	
  	MMIOBASE=0; /* let init() find those */
@@ -543,11 +534,11 @@ static void setlogicalwidth(int width)
 
 static int linear(int op, int param)
 {
-	if (op==LINEAR_ENABLE){ is_linear=1; return 0;}
-	if (op==LINEAR_DISABLE){ is_linear=0; return 0;}
-	if (op==LINEAR_QUERY_BASE) { return LINEARBASE ;}
-	if (op == LINEAR_QUERY_RANGE || op == LINEAR_QUERY_GRANULARITY) return 0;
-	else return -1;
+	if (op==LINEAR_DISABLE || op==LINEAR_ENABLE) return 0;
+	if (op==LINEAR_QUERY_BASE) return __svgalib_linear_mem_base;
+	if (op == LINEAR_QUERY_RANGE || op == LINEAR_QUERY_GRANULARITY)
+		return 0;       /* No granularity or range. */
+	return -1;      /* Unknown function. */
 }
 
 static int cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
@@ -672,15 +663,17 @@ static int init(int force, int par1, int par2)
     twostagepll=0;
 	
 	if(MMIOBASE==0) {
- 		unsigned long buf[64];
+ 		unsigned int buf[64];
  		int found;
  		
- 		found=__svgalib_pci_find_vendor_vga(0x12d2,buf,0);
- 		if (found) {
-  			found=__svgalib_pci_find_vendor_vga(0x10de,buf,0);
-  			if(found)return 0;
+ 		found=__svgalib_pci_find_vendor_vga_pos(0x12d2,buf);
+
+		if (!found) {
+  			found=__svgalib_pci_find_vendor_vga_pos(0x10de,buf);
+  			if(!found) return 1;
  		} 
- 		switch((buf[0]>>20)&0xff){
+
+		switch((buf[0]>>20)&0xff){
   			case 0x1: 
    				dualhead=0;
    				chip=Riva128; 
@@ -760,8 +753,6 @@ static int init(int force, int par1, int par2)
 		chip = par2;
 	};
 	
-	__svgalib_modeinfo_linearset |= IS_LINEAR;
-	
 	__svgalib_mmio_base=MMIOBASE;
 	__svgalib_mmio_size=8*1024*1024;
 	
@@ -828,6 +819,8 @@ static int init(int force, int par1, int par2)
 		fprintf(stderr,"Using nvidia driver, %iKB, Type: %s (NV %x).\n",memory,archs[chip],nvnum);
     };
 
+	__svgalib_modeinfo_linearset |= LINEAR_CAN;
+	
     cardspecs = malloc(sizeof(CardSpecs));
     cardspecs->videoMemory = memory;
     if(chip==Riva128) {
