@@ -797,7 +797,7 @@ static void R128InitFPRegisters(R128SavePtr orig, R128SavePtr save,
 static void RADEONInitPLLRegisters(R128SavePtr save, R128PLLPtr pll,
 				 double dot_clock)
 {
-    unsigned long freq = dot_clock * 100;
+    unsigned int freq = dot_clock * 100;
     struct {
 	int divider;
 	int bitvalue;
@@ -841,7 +841,7 @@ static void RADEONInitPLLRegisters(R128SavePtr save, R128PLLPtr pll,
 static void R128InitPLLRegisters(R128SavePtr save, R128PLLPtr pll,
 				 double dot_clock)
 {
-    unsigned long freq = dot_clock * 100;
+    unsigned int freq = dot_clock * 100;
     struct {
 	int divider;
 	int bitvalue;
@@ -976,7 +976,7 @@ static void r128_unlock(void);
 static void r128_lock(void);
 
 static int r128_memory;
-static int r128_is_linear, r128_linear_base, r128_mmio_base;
+static unsigned int r128_linear_base, r128_mmio_base;
 
 static CardSpecs *cardspecs;
 
@@ -985,16 +985,9 @@ static void r128_setpage(int page)
     page*=2;
     OUTREG(R128_MEM_VGA_WP_SEL, page | ((page+1)<<16));
     OUTREG(R128_MEM_VGA_RP_SEL, page | ((page+1)<<16));
-
-}
-
-static int __svgalib_r128_inlinearmode(void)
-{
-return r128_is_linear;
 }
 
 /* Fill in chipset specific mode information */
-
 static void r128_getmodeinfo(int mode, vga_modeinfo *modeinfo)
 {
 
@@ -1008,9 +1001,7 @@ static void r128_getmodeinfo(int mode, vga_modeinfo *modeinfo)
     modeinfo->flags |= HAVE_EXT_SET;
 
     if (modeinfo->bytesperpixel >= 1) {
-	if(r128_linear_base)modeinfo->flags |= CAPABLE_LINEAR;
-        if (__svgalib_r128_inlinearmode())
-	    modeinfo->flags |= IS_LINEAR | LINEAR_MODE;
+		if(r128_linear_base)modeinfo->flags |= CAPABLE_LINEAR;
     }
 }
 
@@ -1041,7 +1032,9 @@ static int r128_modeavailable(int mode)
     ModeTiming *modetiming;
     ModeInfo *modeinfo;
 
-    modeinfo = __svgalib_createModeInfoStructureForSvgalibMode(mode);
+    /* On radeon's 320x200x256 (INT13) only works with the real banked mem */
+    if ((chiptype==Radeon) && (mode==G320x200x256) && __svgalib_emulatepage)
+        return 0;
 
     if (IS_IN_STANDARD_VGA_DRIVER(mode))
 	return __svgalib_vga_driverspecs.modeavailable(mode);
@@ -1084,18 +1077,22 @@ static int r128_setmode(int mode, int prv_mode)
     ModeInfo *modeinfo;
 
     if (IS_IN_STANDARD_VGA_DRIVER(mode)) {
-	return __svgalib_vga_driverspecs.setmode(mode, prv_mode);
+		//OUTREG(R128_DAC_CNTL, INREG(R128_DAC_CNTL) & ~R128_DAC_8BIT_EN);
+		dac6bits=1;
+		return __svgalib_vga_driverspecs.setmode(mode, prv_mode);
     }
+	
     if (!r128_modeavailable(mode))
-	return 1;
+		return 1;
 
     modeinfo = __svgalib_createModeInfoStructureForSvgalibMode(mode);
 
     modetiming = malloc(sizeof(ModeTiming));
-    if (__svgalib_getmodetiming(modetiming, modeinfo, cardspecs)) {
-	free(modetiming);
-	free(modeinfo);
-	return 1;
+
+	if (__svgalib_getmodetiming(modetiming, modeinfo, cardspecs)) {
+		free(modetiming);
+		free(modeinfo);
+		return 1;
     }
 
     moderegs = malloc(R128_TOTAL_REGS);
@@ -1125,8 +1122,7 @@ static void r128_lock(void)
 /* Indentify chipset, initialize and return non-zero if detected */
 static int r128_test(void)
 {
-    return r128_init(0,0,0);
-    return 1;
+    return !r128_init(0,0,0);
 }
 
 
@@ -1155,11 +1151,11 @@ static void r128_setlogicalwidth(int width)
 
 static int r128_linear(int op, int param)
 {
-    if (op==LINEAR_ENABLE){r128_is_linear=1; return 0;};
-    if (op==LINEAR_DISABLE){r128_is_linear=0; return 0;};
-    if (op==LINEAR_QUERY_BASE) return r128_linear_base;
-    if (op == LINEAR_QUERY_RANGE || op == LINEAR_QUERY_GRANULARITY) return 0;		/* No granularity or range. */
-        else return -1;		/* Unknown function. */
+    if (op==LINEAR_DISABLE || op==LINEAR_ENABLE) return 0;
+    if (op==LINEAR_QUERY_BASE) return __svgalib_linear_mem_base;
+    if (op == LINEAR_QUERY_RANGE || op == LINEAR_QUERY_GRANULARITY)
+        return 0;       /* No granularity or range. */
+    return -1;      /* Unknown function. */
 }
 
 static int r128_match_programmable_clock(int clock)
@@ -1181,8 +1177,8 @@ static unsigned int cur_colors[16*2];
 
 static int r128_cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
     int i, j;
-    unsigned long *b3;
-    unsigned long l1, l2;
+    unsigned int *b3;
+    unsigned int l1, l2;
     
     switch(cmd){
         case CURSOR_INIT:
@@ -1205,7 +1201,7 @@ static int r128_cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
             break;
         case CURSOR_IMAGE:
             i=r128_memory*1024-(p1+1)*4096;
-            b3=(unsigned long *)p5;
+            b3=(unsigned int *)p5;
             switch(p2) {
                 case 0:
                     cur_colors[p1*2]=p3;
@@ -1216,14 +1212,14 @@ static int r128_cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
                         l2=*(b3+32+j); /* mask */
                         l1=BE32(l1);
                         l2=BE32(l2);
-                        *(unsigned long *)(LINEAR_POINTER+i+16*j)=~l2;
-                        *(unsigned long *)(LINEAR_POINTER+i+16*j+4)=0xffffffff;
-                        *(unsigned long *)(LINEAR_POINTER+i+16*j+8)=l1&l2;
-                        *(unsigned long *)(LINEAR_POINTER+i+16*j+12)=0;
-                        *(unsigned long *)(LINEAR_POINTER+i+512+16*j)=0xffffffff;
-                        *(unsigned long *)(LINEAR_POINTER+i+512+16*j+4)=0xffffffff;
-                        *(unsigned long *)(LINEAR_POINTER+i+512+16*j+8)=0;
-                        *(unsigned long *)(LINEAR_POINTER+i+512+16*j+12)=0;
+                        *(unsigned int *)(LINEAR_POINTER+i+16*j)=~l2;
+                        *(unsigned int *)(LINEAR_POINTER+i+16*j+4)=0xffffffff;
+                        *(unsigned int *)(LINEAR_POINTER+i+16*j+8)=l1&l2;
+                        *(unsigned int *)(LINEAR_POINTER+i+16*j+12)=0;
+                        *(unsigned int *)(LINEAR_POINTER+i+512+16*j)=0xffffffff;
+                        *(unsigned int *)(LINEAR_POINTER+i+512+16*j+4)=0xffffffff;
+                        *(unsigned int *)(LINEAR_POINTER+i+512+16*j+8)=0;
+                        *(unsigned int *)(LINEAR_POINTER+i+512+16*j+12)=0;
                     }
                 break;
             }
@@ -1305,7 +1301,7 @@ DriverSpecs __svgalib_r128_driverspecs =
 /* Initialize chipset (called after detection) */
 static int r128_init(int force, int par1, int par2)
 {
-    unsigned long buf[64];
+    unsigned int buf[64];
     int found=0, id, NOBIOS=0;
     unsigned char *BIOS_POINTER;
     char chipnames[2][9]={"Rage 128", "Radeon"};
@@ -1319,9 +1315,8 @@ static int r128_init(int force, int par1, int par2)
 
     };
 
-    found=__svgalib_pci_find_vendor_vga(VENDOR_ID,buf,0);
-
-    if(found) return 0;
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
+    if(!found) return 1;
     
     id=(buf[0]>>16)&0xffff;
     
@@ -1361,15 +1356,16 @@ static int r128_init(int force, int par1, int par2)
 
 	if( (id == 0x4158) ||
 		(id == 0x5354)
-		) return 0; /* Mach64/Mach32 */
+		) return 1; /* Mach64/Mach32 */
 	
-    if(chiptype==-1) return 0;
+    if(chiptype==-1) return 1;
     
     r128_linear_base=buf[4]&0xffffff00;
     r128_mmio_base=buf[6]&0xffffff00;
-
-    MMIO_POINTER = mmap(0, 16*1024, PROT_READ | PROT_WRITE, MAP_SHARED, __svgalib_mem_fd,
-       			r128_mmio_base);
+	
+	__svgalib_mmio_size=16*1024;
+	__svgalib_mmio_base= r128_mmio_base;
+	map_mmio();
 
     if(!r128_memory) r128_memory = INREG(R128_CONFIG_MEMSIZE) / 1024;
 
@@ -1378,7 +1374,7 @@ static int r128_init(int force, int par1, int par2)
     CRTOnly		= 1;
     r128_ramtype	= 1;
 
-#ifndef __PPC    
+#ifdef __i386__
     if(__svgalib_secondary) 
 #endif
         NOBIOS=1;
@@ -1431,16 +1427,14 @@ fprintf(stderr,"pll: %i %i %i %i %i\n",pll.reference_freq,pll.reference_div,
     pll.min_pll_freq,    pll.max_pll_freq, pll.xclk);
 #endif
 
-    munmap(MMIO_POINTER, 16*1024);
-
     r128_mapio();
 	
     if (__svgalib_driver_report) {
-	fprintf(stderr,"Using ATI %s driver, %iKB.\n",chipnames[chiptype],r128_memory);
+		fprintf(stderr,"Using ATI %s driver, %iKB.\n",chipnames[chiptype],r128_memory);
     };
+
+	__svgalib_modeinfo_linearset = LINEAR_CAN;
     
-	__svgalib_modeinfo_linearset |= IS_LINEAR;
-	
     cardspecs = malloc(sizeof(CardSpecs));
     cardspecs->videoMemory = r128_memory;
     cardspecs->maxPixelClock4bpp = 75000;	
@@ -1456,16 +1450,14 @@ fprintf(stderr,"pll: %i %i %i %i %i\n",pll.reference_freq,pll.reference_div,
     cardspecs->mapHorizontalCrtc = r128_map_horizontal_crtc;
     cardspecs->matchProgrammableClock=r128_match_programmable_clock;
     __svgalib_driverspecs = &__svgalib_r128_driverspecs;
-    __svgalib_banked_mem_base=0xa0000;
-    __svgalib_banked_mem_size=0x10000;
     __svgalib_linear_mem_base=r128_linear_base;
     __svgalib_linear_mem_size=r128_memory*0x400;
-    __svgalib_mmio_base=r128_mmio_base;
-    __svgalib_mmio_size=16*1024;
-    if(chiptype==Radeon) {
-        __svgalib_banked_mem_base=r128_linear_base;
-        __svgalib_r128_driverspecs.__svgalib_setpage = __svgalib_emul_setpage;
+    
+    __svgalib_banked_mem_base=0xa0000;
+    __svgalib_banked_mem_size=0x10000;
+	if(chiptype==Radeon) {
+//		__svgalib_emulatepage = 2;
     }
 
-    return 1;
+    return 0;
 }
