@@ -84,9 +84,8 @@ static void sisClockLoad(int, unsigned char *);
 static void sis_CPUthreshold(int,int,int *,int *);
 static int compute_vclk(int Clock, int *out_n, int *out_dn, int *out_div, int *out_sbit, int *out_scale);
 
-static int sis_memory;
-static int sis_is_linear, sis_linear_base;
-static int chip;
+static int sis_memory, sis_is_linear, chip;
+static unsigned int sis_linear_base;
 
 static int sis_edo_vram = 0, sis_host_bus = 0, sis_fast_vram = 0,
            sis_pci_burst_on = 0, sis_pci_burst_off = 0;
@@ -105,11 +104,6 @@ static void sis_300_setpage(int page)
         port_out_r(0x3cd+__svgalib_io_reloc,(page&0x0f) | ((page&0x0f)<<4));
 }
 
-static int __svgalib_sis_inlinearmode(void)
-{
-return sis_is_linear;
-}
-
 /* Fill in chipset specific mode information */
 
 static void sis_getmodeinfo(int mode, vga_modeinfo *modeinfo)
@@ -124,9 +118,7 @@ static void sis_getmodeinfo(int mode, vga_modeinfo *modeinfo)
     modeinfo->flags &= ~HAVE_RWPAGE;
 
     if (modeinfo->bytesperpixel >= 1) {
-	if(sis_linear_base)modeinfo->flags |= CAPABLE_LINEAR;
-        if (__svgalib_sis_inlinearmode())
-	    modeinfo->flags |= IS_LINEAR | LINEAR_MODE;
+		if(sis_linear_base)modeinfo->flags |= CAPABLE_LINEAR;
     }
 }
 
@@ -524,11 +516,11 @@ static void sis_lock(void)
 static int sis_test(void)
 {
     int found;
-    long buf[64];
+    unsigned int buf[64];
     
-    found=__svgalib_pci_find_vendor_vga(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
     
-    if(!found&&(
+    if(found&&(
        (((buf[0]>>16)&0xffff)==PCI_CHIP_SG86C201)||
        (((buf[0]>>16)&0xffff)==PCI_CHIP_SG86C202)||
        (((buf[0]>>16)&0xffff)==PCI_CHIP_SG86C205)||
@@ -550,8 +542,7 @@ static int sis_test(void)
        (((buf[0]>>16)&0xffff)==PCI_CHIP_SIS550)||
        (((buf[0]>>16)&0xffff)==PCI_CHIP_SIS650)||
        0)){
-       sis_init(0,0,0);
-       return 1;
+       return !sis_init(0,0,0);
     };
     return 0;
 }
@@ -633,7 +624,7 @@ static int sis_linear(int op, int param)
 static unsigned char cur_colors[16*6];
 
 static int sis_cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
-    unsigned long *b3;
+    unsigned int *b3;
     int i, j, k, l; 
     uint32_t l1, l2;
     unsigned char c;
@@ -675,7 +666,7 @@ static int sis_cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
             i=sis_memory*1024-(16-p1)*1024;
             if((chip==SIS_6326)&&(sis_memory>4096))
                i-=4096*1024; /* 6326 can't put cursor beyond 4MB */
-            b3=(unsigned long *)p5;
+            b3=(unsigned int *)p5;
             switch(p2) {
                 case 0:
                     cur_colors[p1*6]=(p3&0xff0000)>>16;
@@ -711,7 +702,7 @@ static int sis_cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
 }       
 
 static int sis_300_cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
-    unsigned long *b3;
+    unsigned int *b3;
     int i, j; 
     uint32_t l1, l2;
     
@@ -741,7 +732,7 @@ static int sis_300_cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
         case CURSOR_IMAGE:
             i=(sis_memory-16+p1)*1024;
             if(i>0x4000000)i&=0x3ffffff;
-            b3=(unsigned long *)p5;
+            b3=(unsigned int *)p5;
             switch(p2) {
                 case 0:
                     cur_colors[p1*6]=(p3&0xff0000)>>16;
@@ -823,7 +814,7 @@ DriverSpecs __svgalib_sis_driverspecs =
 
 static int sis_init(int force, int par1, int par2)
 {
-    unsigned long buf[64];
+    unsigned int buf[64];
     int pci_id;
     int found=0;
 
@@ -835,10 +826,10 @@ static int sis_init(int force, int par1, int par2)
 
     };
 
-    found=__svgalib_pci_find_vendor_vga(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
     sis_linear_base=0;
     chip=0;
-    if (!found){
+    if (found){
        sis_linear_base=buf[4]&0xffffff00;
        pci_id=(buf[0]>>16)&0xffff;
        switch(pci_id) {
@@ -875,7 +866,7 @@ static int sis_init(int force, int par1, int par2)
                 break;
        };
     } else {
-		return -1;
+		return 1;
 	}
     
     if(chip>=SIS_5597) {
@@ -931,7 +922,7 @@ static int sis_init(int force, int par1, int par2)
     };
 
     if (__svgalib_driver_report) {
-	fprintf(stderr,"Using SIS driver, %iKB. Chiptype=%i\n",sis_memory,chip);
+		fprintf(stderr,"Using SIS driver, %iKB. Chiptype=%i\n",sis_memory,chip);
     };
 
     /* program the 25 and 28 Mhz clocks */
@@ -952,7 +943,7 @@ static int sis_init(int force, int par1, int par2)
        write_xr(0x38,temp);
     }
 	if(chip>=SIS_300) {
-    	__svgalib_modeinfo_linearset |= IS_LINEAR;
+    	__svgalib_modeinfo_linearset |= LINEAR_CAN;
 	}
 
     cardspecs = malloc(sizeof(CardSpecs));
