@@ -24,8 +24,8 @@ static void unlock(void);
 static void lock(void);
 
 static int memory, chip, NewClockCode, shadowNew, lcdactive, lcdmode, stretch=1;
-static int frequency=0;
-static int is_linear, linear_base, mmio_base;
+static int frequency=0, is_linear;
+static unsigned int linear_base, mmio_base;
 
 static CardSpecs *cardspecs;
 
@@ -113,11 +113,6 @@ static void setpage(int page)
     OUTB(0x3D9, page);
 }
 
-static int __svgalib_inlinearmode(void)
-{
-return is_linear;
-}
-
 /* Fill in chipset specific mode information */
 
 static void getmodeinfo(int mode, vga_modeinfo *modeinfo)
@@ -133,8 +128,6 @@ static void getmodeinfo(int mode, vga_modeinfo *modeinfo)
 
     if (modeinfo->bytesperpixel >= 1) {
 		if(linear_base)modeinfo->flags |= CAPABLE_LINEAR;
-    	if (__svgalib_inlinearmode())
-	    	modeinfo->flags |= IS_LINEAR | LINEAR_MODE;
     }
 }
 
@@ -524,7 +517,7 @@ static void TGUISetClock(int clock, uint8_t *a, uint8_t *b)
 
 static void initializemode(unsigned char *moderegs,
 			    ModeTiming * modetiming, ModeInfo * modeinfo, int mode)
-{ /* long k; */
+{ /* int k; */
 
     int offset=0, protect=0, fullsize=0, MUX;
     int clock;
@@ -873,7 +866,6 @@ static int setmode(int mode, int prv_mode)
 	
 	if (!modeavailable(mode)) return 1;
 	
-	__svgalib_modeinfo_linearset &= ~IS_LINEAR;
 	is_linear=0;
 
     modeinfo = __svgalib_createModeInfoStructureForSvgalibMode(mode);
@@ -916,12 +908,12 @@ static void lock(void)
 
 static int test(void)
 {
-    unsigned long buf[64];
+    unsigned int buf[64];
     int found, id;
     
-    found=__svgalib_pci_find_vendor_vga(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
     id=(buf[0]>>16)&0xffff;
-    if(found)return 0;
+    if(!found)return 0;
     if( !init(0,0,0)) return 1;
     return 0;
 }
@@ -1029,7 +1021,7 @@ static int findcolor(int rgb) {
 
 static int cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
     int i, j;
-    unsigned long *b3, *b4;
+    unsigned int *b3, *b4;
     
     switch(cmd){
         case CURSOR_INIT:
@@ -1081,8 +1073,8 @@ static int cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
             break;
         case CURSOR_IMAGE:
             i=memory*1024-(p1+1)*1024;
-            b3=(unsigned long *)p5;
-            b4=(unsigned long *)(LINEAR_POINTER+i);
+            b3=(unsigned int *)p5;
+            b4=(unsigned int *)(LINEAR_POINTER+i);
             if (!is_linear){
                 int t;
                 OUTB(0x3CE, MiscExtFunc);
@@ -1163,7 +1155,7 @@ DriverSpecs __svgalib_trident_driverspecs =
 
 static int init(int force, int par1, int par2)
 {
-    unsigned long buf[64];
+    unsigned int buf[64];
     int rev, i, id;
     int found=0;
     char *chipnames[]={
@@ -1185,10 +1177,10 @@ static int init(int force, int par1, int par2)
 
     };
 
-    found=__svgalib_pci_find_vendor_vga(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
     linear_base=0;
     id=(buf[0]>>16)&0xffff;
-    if(found)
+    if(!found)
         return 1;
 
     linear_base=buf[4]&0xffff0000;
