@@ -83,12 +83,9 @@ static void vesa_getmodeinfo(int mode, vga_modeinfo *modeinfo)
     modeinfo->flags |= vesa_read_write;  /* sets HAVE_RWPAGE bit */
 
     /* for linear need VBE2 */
-    if(vesa_chiptype>=1)
-      if (modeinfo->bytesperpixel >= 1) {
-	modeinfo->flags |= CAPABLE_LINEAR;
-        if (__svgalib_vesa_inlinearmode())
-	    modeinfo->flags |= IS_LINEAR | LINEAR_MODE;
-      }
+    if((vesa_chiptype>=1) && (modeinfo->bytesperpixel >= 1)) {
+		modeinfo->flags |= CAPABLE_LINEAR;
+	}
       
     /* to get the logical scanline width */
     memset(&vesa_r, 0, sizeof(vesa_r));
@@ -117,7 +114,8 @@ static int vesa_saveregs(uint8_t regs[])
   vesa_r.ecx=__svgalib_VESA_savebitmap;
   __svgalib_LRMI_callbacks->rm_int(0x10,&vesa_r);
   memcpy(&regs[VGA_TOTAL_REGS],buf,vesa_regs_size);  
-    return vesa_regs_size;
+  
+  return vesa_regs_size;
 }
 
 /* Set chipset-specific registers */
@@ -155,9 +153,9 @@ static int vesa_modeavailable(int mode)
 
     modetiming = malloc(sizeof(ModeTiming));
     if (__svgalib_getmodetiming(modetiming, modeinfo, cardspecs)) {
-	free(modetiming);
-	free(modeinfo);
-	return 0;
+		free(modetiming);
+		free(modeinfo);
+		return 0;
     }
     free(modetiming);
     free(modeinfo);
@@ -406,7 +404,7 @@ static int vesa_init(int force, int par1, int par2)
 
     m=mmap(0,0x502,PROT_READ,MAP_SHARED,__svgalib_mem_fd,0);
     
-    address=((long)*(unsigned short *)(m+64))+(((long)*(unsigned short *)(m+66))<<4);
+    address=((int)*(unsigned short *)(m+64))+(((int)*(unsigned short *)(m+66))<<4);
     if((address<0xa0000)||(address>0xfffff)) {
        	fprintf(stderr, "Real mode int 0x10 at 0x%08x handler not in ROM.\n",address);
         fprintf(stderr, "Try running vga_reset.\n");
