@@ -230,7 +230,7 @@ static char *kbd_process_option(int option, int mode, char **nptr) {
   store_event:
 
 #ifdef DEBUG_KEYBOARD
-  fprintf(stderr," Fake Mouse Event: scancode: %ld;  type: %ld;  data: %ld;  flags: %ld\n", (long)scancode, (long)type, (long)data, (long)flags);
+  fprintf(stderr," Fake Mouse Event: scancode: %d;  type: %d;  data: %d;  flags: %d\n", scancode, (int)type, data, (int)flags);
 #endif
 	   if ( ! expand_events(n))
 	     return ptr;
@@ -527,11 +527,11 @@ static int keyboard_getevents(int wait)
                     flags = event -> flags;
                     request_at_down = (event -> flags & FMEF_AT_PRESS)  ?  1 : 0;
 #ifdef DEBUG_KEYBOARD
-                    fprintf(stderr," event type: %ld;  flags: %ld;  data: %ld; is_pressed: %ld\n", (long)event->type, (long)flags, (long)event->data, (long)is_pressed);
+                    fprintf(stderr," event type: %d;  flags: %d;  data: %d; is_pressed: %d\n", (int)event->type, flags, event->data, (int)is_pressed);
 #endif
                     if (flags & FMEF_AT_BOTH  ||  request_at_down == is_pressed) {
 #ifdef DEBUG_KEYBOARD
-                        fprintf(stderr,"   flags: %ld\n", (long)flags);
+                        fprintf(stderr,"   flags: %d\n", flags);
 #endif
                         if (  (! (flags & FMEF_TRIGGERED))  ||  flags & FMEF_REPEAT) {
 #ifdef DEBUG_KEYBOARD
@@ -580,8 +580,8 @@ static int keyboard_getevents(int wait)
               __svgalib_mouse_eventhandler(but, dx, dy, dz, 0, 0, 0);
 
 #ifdef DEBUG_KEYBOARD
-            fprintf(stderr,"\tfake_mouse_event triggered; but: %ld; dx: %ld; dy: %ld; dz: %ld\n",
-                   (long)but, (long)dx, (long)dy, (long)dz);
+            fprintf(stderr,"\tfake_mouse_event triggered; but: %d; dx: %d; dy: %d; dz: %d\n",
+                   but, dx, dy, dz);
 #endif
           }
             }
