@@ -37,7 +37,7 @@ typedef struct ML {
 } ModeList;
 
 static void *
- Malloc(unsigned long bytes)
+ Malloc(size_t bytes)
 {
     void *res;
 
