@@ -17,7 +17,7 @@ extern "C"
 {
 #endif
 
-#define SVGALIB_VER 0x010921
+#define SVGALIB_VER 0x010922
 
 #define TEXT 	     0		/* Compatible with VGAlib v1.2 */
 #define G320x200x16  1
@@ -255,13 +255,18 @@ extern "C"
 #define IS_MODEX			   4	/* ModeX style 256 colors */
 #define IS_DYNAMICMODE		   8	/* Dynamic defined mode */
 #define CAPABLE_LINEAR		  16	/* Can go to linear addressing mode. */
-#define IS_LINEAR			  32	/* Linear addressing can be used. */
+#define IS_LINEAR			  32	/* Linear addressing has been set by vga_setlinearaddressing. */
 #define EXT_INFO_AVAILABLE	  64	/* Returned modeinfo contains valid extended fields */
 #define RGB_MISORDERED		 128	/* Mach32 32bpp uses 0BGR instead of BGR0. */
 #define HAVE_EXT_SET		 256	/* vga_ext_set() available */
-#define LINEAR_MODE			 512	/* Linear mode is enabled */
+#define LINEAR_CAN			 512	/* Linear mode can be used (even if not set). */
 #define IOCTL_SETDISPLAY	1024	/* The card supports ioctl method for setting display
 										start at next vertical blank time */
+#define LINEAR_USE (IS_LINEAR|LINEAR_CAN)
+
+/* Don't use linear in vga modes (even 320x200x256). It does not work with some
+ * cards. */
+#define CAN_USE_LINEAR (__svgalib_modeinfo_linearset & LINEAR_USE & !STDVGAMODE(CM))
 
     typedef struct {
 	int width;
@@ -587,8 +592,8 @@ extern void vga_waitvtactive(void);
 #ifdef _SVGALIB_LRMI
 typedef struct {
     int (*rm_init)(void);
-    int (*rm_call)(struct vm86_regs *r);
-    int (*rm_int)(int interrupt, struct vm86_regs *r);
+    int (*rm_call)(struct LRMI_regs *r);
+    int (*rm_int)(int interrupt, struct LRMI_regs *r);
     void * (*rm_alloc_real)(int size);
     void (*rm_free_real)(void *m);
 } LRMI_callbacks;
