@@ -31,7 +31,7 @@ vga_cardinfo *vga_getcardinfo(void) {
     vci->version = 0x200;
     vci->size = sizeof(vga_cardinfo);
     vci->chipset = __svgalib_chipset;
-    vci->physmem = __svgalib_linear_mem_base;
+    vci->physmem = __svgalib_linear_mem_phys_addr;
 	vci->physmemsize = __svgalib_linear_mem_size;
 	vci->linearmem = LINEAR_POINTER;
     
@@ -40,22 +40,22 @@ vga_cardinfo *vga_getcardinfo(void) {
 
 void vga_waitretrace(void)
 {
-#if 1
-    ioctl(__svgalib_mem_fd, SVGAHELPER_WAITRETRACE, NULL);
-#else
-    if (__svgalib_driverspecs->emul && __svgalib_driverspecs->emul->waitretrace) {
-        __svgalib_driverspecs->emul->waitretrace();
-    } else {
-	while (!(__svgalib_inis1() & 8));
-	while (__svgalib_inis1() & 8);
+    if(!__svgalib_nohelper)
+        ioctl(__svgalib_mem_fd, SVGAHELPER_WAITRETRACE, NULL);
+    else
+    {
+        if (__svgalib_driverspecs->emul && __svgalib_driverspecs->emul->waitretrace) {
+            __svgalib_driverspecs->emul->waitretrace();
+        } else {
+            while (!(__svgalib_inis1() & 8));
+            while (__svgalib_inis1() & 8);
+        }
     }
-#endif
 }
 
-static void *__svgalib_linearframebuffer;
 /*
  * The way IS_LINEAR gets indicated is rather convoluted; if the driver
- * has EXT_INFO_AVAILABLE, setlinearaddressing will enable
+ * is CAPABLE_LINEAR, setlinearaddressing will enable
  * the flag in __svgalib_linearset which gets set in the modeinfo by
  * vga_getmodeinfo(). The driver must turn off the flag in
  * __svgalib_linearset if linear addressing gets disabled (e.g. when
@@ -71,9 +71,10 @@ unsigned char *
 
     DTP((stderr,"getgraphmem\n"));
 
-    if (__svgalib_modeinfo_linearset & LINEAR_MODE )
-	return __svgalib_linearframebuffer;
-    return GM;
+    if (__svgalib_modeinfo_linearset & IS_LINEAR )
+		return LINEAR_POINTER;
+    
+	return GM;
 }
 
 /*
@@ -94,15 +95,15 @@ int vga_setlinearaddressing(void)
     if (!(modeinfo->flags&CAPABLE_LINEAR)) return -1;
 
     (*lfn) (LINEAR_ENABLE, 0);
-    __svgalib_linearframebuffer = LINEAR_POINTER;
 
-    if ((long) __svgalib_linearframebuffer == -1) {
-	/* Shouldn't happen. */
-	(*lfn) (LINEAR_DISABLE, 0);
-	return -1;
+    if (LINEAR_POINTER==NULL) {
+		/* Shouldn't happen. */
+		(*lfn) (LINEAR_DISABLE, 0);
+    	__svgalib_modeinfo_linearset &= ~(IS_LINEAR);
+		return -1;
     }
     
-    __svgalib_modeinfo_linearset |= IS_LINEAR | LINEAR_MODE;
+    __svgalib_modeinfo_linearset |= IS_LINEAR;
 
     graph_mem = LINEAR_POINTER;
 
