@@ -51,7 +51,7 @@ main (void)
       printf ("Not a Cirrus.\n");
       printf ("Continue anyway (y/n)?\n");
       if (getchar () != 'y')
-	exit (-1);
+	return -1;
     }
 
   /* Unlock extended registers. */
@@ -85,5 +85,5 @@ main (void)
   OUTB (0x3c5, NEW_MCLK);
   printf ("New MCLK value: %02x\n", NEW_MCLK);
 
-  exit (0);
+  return 0;
 }
